@@ -12,19 +12,19 @@ class UserException(Exception):
 
 class User(PropertiedObject):
     '''Store information about a BGG User. The init function takes a list of valid
-    proprties defined by boardgame.valid_properties. Properties that are lists can
+    proprties defined by boardgame.__slots__. Properties that are lists can
     be given as a single item or as a list.'''
 
     # This should really contain the correct types as well...
-    valid_properties = [
+    __slots__ = [
         'name', 'hot10', 'top10', 'firstname', 'lastname', 'yearregistered', 'lastlogin',
         'stateorprovince', 'country', 'traderating', 'bgid'
     ]
 
     def __init__(self, **kwargs):
-        self.valid_properties = User.valid_properties
-        super(User, self).__init__(**kwargs)
-        # force lists to be lists
+        for k, v in kwargs.items():
+            setattr(self, k, v)
+
         for l in ['top10', 'hot10']:
             try:
                 if type(getattr(self, l)) != list:
@@ -39,7 +39,9 @@ class User(PropertiedObject):
         return self.__unicode__().encode('utf-8').strip()
 
     def dump(self):
-        super(User, self).dump('%s' % self.name)
+        log.debug('%s' % self.name)
+        for a in Rating.__slots__:
+            log.debug('\t%s: %s' % (a, getattr(self, a)))
 
     @property
     def fullname(self):
